Index: chrome/browser/safe_browsing/client_side_detection_host.h |
diff --git a/chrome/browser/safe_browsing/client_side_detection_host.h b/chrome/browser/safe_browsing/client_side_detection_host.h |
index ba9af18a0009e29d1f89a9bcc09ecd1cdf59da33..0e77f0afe90c53b4019f71cea960a58ca8b0505a 100644 |
--- a/chrome/browser/safe_browsing/client_side_detection_host.h |
+++ b/chrome/browser/safe_browsing/client_side_detection_host.h |
@@ -117,8 +117,10 @@ class ClientSideDetectionHost : public TabContentsObserver, |
base::ScopedCallbackFactory<ClientSideDetectionHost> cb_factory_; |
// Unique page ID of the most recent unsafe site that was loaded in this tab. |
int unsafe_unique_page_id_; |
+ scoped_ptr<SafeBrowsingService::UnsafeResource> unsafe_resource_; |
DISALLOW_COPY_AND_ASSIGN(ClientSideDetectionHost); |
}; |
@@ -117,8 +117,10 @@ class ClientSideDetectionHost : public TabContentsObserver, |
base::ScopedCallbackFactory<ClientSideDetectionHost> cb_factory_; |
- // Unique page ID of the most recent unsafe site that was loaded in this tab. |
+ // Unique page ID of the most recent unsafe site that was loaded in this tab |
+ // as well as the UnsafeResource. |
int unsafe_unique_page_id_; |